## webSpider_Douban

## V1:
返回排行榜电影名字

Output the title-lists of top ten latest movie charts to a csv file

## V2:
返回豆瓣排行榜上前十部电影的数据细节(不再只是电影名!); 表头新增更新时间

Output the information of each movie in the top ten latest movie charts to a csv file

### V2.1:
添加适当注释并优化了有利于分析的数据细节

## V3:
Coming soon...
